@@ -1,5 +1,5 @@
 test_that("tide_height works", {
-  expect_null(chk::check_data(tide_height(),
+  expect_error(chk::check_data(tide_height(),
     values = list(
       Station = "", DateTime = Sys.time(), TideHeight = 1
     ),
@@ -7,7 +7,7 @@ test_that("tide_height works", {
     key = "DateTime",
     exclusive = TRUE,
     order = TRUE
-  ))
+  ), NA)
 
   expect_is(tide_height(stations = ".*"), "data.frame")
 })
